IsAddressKind

Trait IsAddressKind 

pub trait IsAddressKind: NonExtensible { }
Restricts the inhabitants that a generic parameter can take. This is used in the context of Address to carry certain predicates at the type-level and enable infaillible methods on addresses.

See also: Address::as_shelley and/or Address::as_byron.

Implementors