Encode

Trait Encode 

pub trait Encode<C> {
    // Required method
    fn encode<W>(
        &self,
        e: &mut Encoder<W>,
        ctx: &mut C,
    ) -> Result<(), Error<<W as Write>::Error>>
       where W: Write;

    // Provided method
    fn is_nil(&self) -> bool { ... }
}
A type that can be encoded to CBOR.

If this type’s CBOR encoding is meant to be decoded by Decode impls derived with [minicbor_derive] it is advisable to only produce a single CBOR data item. Tagging, maps or arrays can and should be used for multiple values.

Required Methods

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Encode a value of this type using the given Encoder.

In addition to the encoder a user provided encoding context is given as another parameter. Most implementations of this trait do not need an encoding context and should be completely generic in the context type. In cases where a context is needed and the Encode impl type is meant to be combined with other types that require a different context type, it is preferrable to constrain the context type variable C with a trait bound instead of fixing the type.

Provided Methods

fn is_nil(&self) -> bool

Is this value of Self a nil value?

This method is primarily used by minicbor-derive.

Some types have a special value to denote the concept of “nothing”, aka nil. An example is the Option type with its None value. This method–if overriden–allows checking if a value is such a special nil value.

NB: A type implementing Encode with an overriden Encode::is_nil method should also override Decode::nil if it implements Decode at all.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl Encode<()> for AddrDistr



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut (), ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<'b, Ctx> Encode<Ctx> for MintedBlock<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedBlock<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedBlockBody<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedEbBlock<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedTx<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedTxPayload<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<C> Encode<C> for IpAddr

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SocketAddr

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for bool



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for char



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for f32



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for f64



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for i8



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for i16



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for i32



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for i64



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for isize

Available on 64-bit only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for str



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for u8



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for u16



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for u32



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for u64



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for ()



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for usize

Available on 64-bit only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for CString

Available on crate feature alloc only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for String

Available on crate feature alloc only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for CStr



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Ipv4Addr

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Ipv6Addr

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SocketAddrV4

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SocketAddrV6

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<i8>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<i16>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<i32>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<i64>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<isize>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<u8>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<u16>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<u32>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<u64>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZero<usize>



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicBool



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicI8



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicI16



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicI32



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicI64



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicIsize



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicU8



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicU16



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicU32



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicU64



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AtomicUsize



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Duration



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Path

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for PathBuf

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SystemTime

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AddrAttrProperty



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AddrType



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Anchor



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AnyCbor



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AnyUInt



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for AuxiliaryData



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for BigInt



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for BlockSig



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for BoundedBytes



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Certificate



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Certificate



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Constitution



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for DRep



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for DRepVotingThresholds



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for EmptyMap



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for GovAction



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for GovActionId



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for InstantaneousRewardSource



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for InstantaneousRewardTarget



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Metadatum



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NativeScript



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for NonZeroInt



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for PlutusData



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for PoolVotingThresholds



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for PositiveCoin



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for ProposalProcedure



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for RationalNumber



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Redeemers



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Relay



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SpendingData



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Ssc



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for SscProof



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for StakeCredential



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Twit



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for TxFeePol



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for TxIn



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Value



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Value



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Vote



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for Voter



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C> Encode<C> for VotingProcedure



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, A> Encode<C> for Constr<A>
where A: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, A> Encode<C> for MaybeIndefArray<A>
where A: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, I, const T: u64> Encode<C> for TagWrap<I, T>
where I: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, K, V> Encode<C> for BTreeMap<K, V>
where K: Encode<C> + Eq + Ord, V: Encode<C>,

Available on crate feature alloc only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, K, V> Encode<C> for KeyValuePairs<K, V>
where K: Encode<C> + Clone, V: Encode<C> + Clone,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, K, V> Encode<C> for NonEmptyKeyValuePairs<K, V>
where K: Encode<C> + Clone, V: Encode<C> + Clone,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, K, V, S> Encode<C> for HashMap<K, V, S>
where K: Encode<C> + Eq + Hash, V: Encode<C>, S: BuildHasher,

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, P> Encode<C> for OrderPreservingProperties<P>
where P: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Cow<'_, T>
where T: Encode<C> + ToOwned + ?Sized,

Available on crate feature alloc only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Bound<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Option<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



fn is_nil(&self) -> bool



impl<C, T> Encode<C> for &T
where T: Encode<C> + ?Sized,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for &mut T
where T: Encode<C> + ?Sized,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for [T]
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Box<T>
where T: Encode<C> + ?Sized,

Available on crate feature alloc only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for BinaryHeap<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for BTreeSet<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for LinkedList<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for VecDeque<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Vec<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Cell<T>
where T: Encode<C> + Copy,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for RefCell<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PhantomData<T>



fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Wrapping<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Range<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for RangeFrom<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for RangeInclusive<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for RangeTo<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for RangeToInclusive<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for CborWrap<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for KeepRaw<'_, T>



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for NonEmptySet<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Nullable<T>
where T: Encode<C> + Clone,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PseudoDatumOption<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PseudoScript<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PseudoScript<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PseudoTransactionOutput<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for PseudoTransactionOutput<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for Set<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T> Encode<C> for ZeroOrOneArray<T>
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T, E> Encode<C> for Result<T, E>
where T: Encode<C>, E: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T, S> Encode<C> for HashSet<T, S>
where T: Encode<C>, S: BuildHasher,

Available on crate feature std only.


fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, T, const N: usize> Encode<C> for [T; N]
where T: Encode<C>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, const BYTES: usize> Encode<C> for Hash<BYTES>



fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<C, const N: usize> Encode<C> for SkipCbor<N>



fn encode<W>( &self, _e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx> Encode<Ctx> for Address



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for AddressPayload



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BVerMod



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Block



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Block



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BlockBody



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BlockCons



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BlockHead



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BlockHeadEx



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BlockProof



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for BootstrapWitness



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ByronAddress



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Bytes



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for CostModels



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for CostModels



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Dlg



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for EbBlock



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for EbbCons



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for EbbHead



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ExUnitPrices



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ExUnitPrices



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ExUnits



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for HeaderBody



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for HeaderBody



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Int



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Language



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Language



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Language



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Lwdlg



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for MoveInstantaneousReward



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for NetworkId



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Nonce



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for NonceVariant



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for OperationalCert



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for PoolMetadata



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ProtocolParamUpdate



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ProtocolParamUpdate



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ProtocolParamUpdate



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Redeemer



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Redeemer



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for RedeemerPointer



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for RedeemerTag



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for RedeemerTag



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for RedeemersKey



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for RedeemersValue



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for ShelleyMaAuxiliaryData



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for SlotId



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for TransactionBody



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for TransactionInput



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for TransactionOutput



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Tx



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Tx



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for TxOut



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for TxPayload



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Up



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for UpProp



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for UpVote



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Update



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Update



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for Update



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for VKeyWitness



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for VrfCert



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for WitnessSet



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for WitnessSet



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx> Encode<Ctx> for WitnessSet



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, A> Encode<Ctx> for (A,)
where A: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B> Encode<Ctx> for (A, B)
where A: Encode<Ctx>, B: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C> Encode<Ctx> for (A, B, C)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D> Encode<Ctx> for (A, B, C, D)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E> Encode<Ctx> for (A, B, C, D, E)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F> Encode<Ctx> for (A, B, C, D, E, F)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G> Encode<Ctx> for (A, B, C, D, E, F, G)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H> Encode<Ctx> for (A, B, C, D, E, F, G, H)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I> Encode<Ctx> for (A, B, C, D, E, F, G, H, I)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>, O: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>, O: Encode<Ctx>, P: Encode<Ctx>,



fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,



impl<Ctx, T1> Encode<Ctx> for PseudoHeader<T1>
where T1: Encode<Ctx>,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1> Encode<Ctx> for PseudoHeader<T1>
where T1: Encode<Ctx>,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1> Encode<Ctx> for PseudoTransactionBody<T1>
where T1: Encode<Ctx>,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1> Encode<Ctx> for PseudoTransactionBody<T1>
where T1: Encode<Ctx>,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoPostAlonzoTransactionOutput<T1, T2, T3>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoTx<T1, T2, T3>
where T1: Encode<Ctx> + Clone, T2: Encode<Ctx> + Clone, T3: Encode<Ctx> + Clone,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoTx<T1, T2, T3>
where T1: Encode<Ctx> + Clone, T2: Encode<Ctx> + Clone, T3: Encode<Ctx> + Clone,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1, T2, T3, T4> Encode<Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>, T4: Encode<Ctx> + Clone,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, T1, T2, T3, T4> Encode<Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>, T4: Encode<Ctx> + Clone,



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,



impl<Ctx, const VERSION: usize> Encode<Ctx> for PlutusScript<VERSION>



fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Implementors



impl<'b, C> Encode<C> for Token<'b>



impl<C> Encode<C> for IanaTag

Source

impl<C> Encode<C> for Input

Source

impl<C> Encode<C> for Output

Source

impl<C> Encode<C> for cardano_sdk::PlutusData<'_>

Source

impl<C> Encode<C> for cardano_sdk::Value<u64>



impl<C> Encode<C> for ByteSlice



impl<C> Encode<C> for ByteVec

Available on crate feature alloc only.


impl<C> Encode<C> for cardano_sdk::cbor::data::Int



impl<C> Encode<C> for Tag



impl<C, I, K, V> Encode<C> for MapIter<I>
where I: Iterator<Item = (K, V)> + Clone, K: Encode<C>, V: Encode<C>,



impl<C, I, T> Encode<C> for ArrayIter<I>
where I: Iterator<Item = T> + Clone, T: Encode<C>,

Source

impl<C, State: IsTransactionBodyState> Encode<C> for Transaction<State>



impl<C, const N: u64, T> Encode<C> for Tagged<N, T>
where T: Encode<C>,



impl<C, const N: usize> Encode<C> for ByteArray<N>

Source

impl<Ctx> Encode<Ctx> for Network

Source

impl<Ctx> Encode<Ctx> for PlutusVersion

Source

impl<Ctx> Encode<Ctx> for Hash28

Source

impl<Ctx> Encode<Ctx> for Hash32

Source

impl<Ctx> Encode<Ctx> for Credential

Source

impl<Ctx> Encode<Ctx> for ExecutionUnits

Source

impl<Ctx> Encode<Ctx> for cardano_sdk::NetworkId

Source

impl<Ctx> Encode<Ctx> for cardano_sdk::RedeemerPointer

Source

impl<Ctx, const SIZE: usize> Encode<Ctx> for cardano_sdk::Hash<SIZE>