pub struct Credential(/* private fields */);Expand description
A wrapper around the blake2b-224 hash digest of a key or script.
It behaves like a enum with two variants, although the constructors are kept private to avoid leaking implementation internals. One can manipulate either of the two variants by using the higher-level API:
If something more fine-grained is needed where either are needed, one may simply use:
Implementations
Sourceimpl Credential
impl Credential
pub const DIGEST_SIZE: usize = 28
Sourcepub fn from_key(hash: Hash<28>) -> Self
pub fn from_key(hash: Hash<28>) -> Self
Construct a credential from a key.
See also key_credential!.
Sourcepub fn from_script(hash: Hash<28>) -> Self
pub fn from_script(hash: Hash<28>) -> Self
Construct a credential from a script.
See also script_credential!.
Sourceimpl Credential
impl Credential
Sourcepub fn select<T>(
&self,
when_key: impl FnMut(Hash<28>) -> T,
when_script: impl FnMut(Hash<28>) -> T,
) -> T
pub fn select<T>( &self, when_key: impl FnMut(Hash<28>) -> T, when_script: impl FnMut(Hash<28>) -> T, ) -> T
Run a computation (possibly the same) for either of the two variants.
examples
assert_eq!(
script_credential!("bd3ae991b5aafccafe5ca70758bd36a9b2f872f57f6d3a1ffa0eb777")
.select(
|_| "is_key".to_string(),
|_| "is_script".to_string(),
),
"is_script"
);assert_eq!(
key_credential!("bd3ae991b5aafccafe5ca70758bd36a9b2f872f57f6d3a1ffa0eb777")
.select(
|hash| format!("Key({hash})"),
|hash| format!("Script({hash})"),
),
"Key(bd3ae991b5aafccafe5ca70758bd36a9b2f872f57f6d3a1ffa0eb777)"
)Trait Implementations
Sourceimpl Clone for Credential
impl Clone for Credential
Sourcefn clone(&self) -> Credential
fn clone(&self) -> Credential
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Credential
impl Debug for Credential
Sourceimpl<'bytes, Ctx> Decode<'bytes, Ctx> for Credential
impl<'bytes, Ctx> Decode<'bytes, Ctx> for Credential
Sourceimpl Default for Credential
impl Default for Credential
Sourceimpl Display for Credential
impl Display for Credential
Sourceimpl<Ctx> Encode<Ctx> for Credential
impl<Ctx> Encode<Ctx> for Credential
Sourceimpl From<&Credential> for [u8; 28]
impl From<&Credential> for [u8; 28]
Sourcefn from(credential: &Credential) -> Self
fn from(credential: &Credential) -> Self
Converts to this type from the input type.
Sourceimpl From<&Credential> for Hash<28>
impl From<&Credential> for Hash<28>
Sourcefn from(credential: &Credential) -> Self
fn from(credential: &Credential) -> Self
Converts to this type from the input type.
Sourceimpl From<&ShelleyPaymentPart> for Credential
impl From<&ShelleyPaymentPart> for Credential
Sourceimpl From<&StakePayload> for Credential
impl From<&StakePayload> for Credential
Sourceimpl From<&VerificationKey> for Credential
impl From<&VerificationKey> for Credential
Sourcefn from(key: &VerificationKey) -> Self
fn from(key: &VerificationKey) -> Self
Converts to this type from the input type.
Sourceimpl From<Credential> for ShelleyDelegationPart
impl From<Credential> for ShelleyDelegationPart
Sourcefn from(credential: Credential) -> Self
fn from(credential: Credential) -> Self
Converts to this type from the input type.
Sourceimpl From<Credential> for ShelleyPaymentPart
impl From<Credential> for ShelleyPaymentPart
Sourcefn from(credential: Credential) -> Self
fn from(credential: Credential) -> Self
Converts to this type from the input type.
Sourceimpl From<Credential> for StakeCredential
impl From<Credential> for StakeCredential
Sourcefn from(credential: Credential) -> Self
fn from(credential: Credential) -> Self
Converts to this type from the input type.
Sourceimpl From<StakeCredential> for Credential
impl From<StakeCredential> for Credential
Sourceimpl FromStr for Credential
impl FromStr for Credential
Sourceimpl Ord for Credential
impl Ord for Credential
Sourcefn cmp(&self, other: &Credential) -> Ordering
fn cmp(&self, other: &Credential) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Credential
impl PartialEq for Credential
Sourceimpl PartialOrd for Credential
impl PartialOrd for Credential
Sourceimpl TryFrom<&ShelleyDelegationPart> for Credential
impl TryFrom<&ShelleyDelegationPart> for Credential
impl Eq for Credential
impl StructuralPartialEq for Credential