pub struct SigningKey(/* private fields */);Expand description
An ed25519 signing key (non-extended).
Implementations
Sourceimpl SigningKey
impl SigningKey
pub const SIZE: usize = ed25519::SecretKey::SIZE
Sourcepub unsafe fn leak(key: Self) -> [u8; 32]
pub unsafe fn leak(key: Self) -> [u8; 32]
Convert the [SecretKey] into its compressed byte composition, and leak its bytes into
memory. Only use for storing the key securely or for testing. Additional precautions are
needed to ensure that the leaked bytes are properly de-allocated and cleared.
Safety
This function is not safe because:
- using it removes all the security measure we put in place
to protect your private key: opaque
Debugimpl, zeroisation onDrop, … - you will need to be careful not to leak the bytes
Example
let key: SigningKey = // ...
let _: [u8; SigningKey::SIZE] = unsafe { SigningKey::leak(key) };pub fn sign<T>(&self, msg: T) -> Signature
Sourceimpl SigningKey
impl SigningKey
pub fn to_verification_key(&self) -> VerificationKey