PlutusData

Struct PlutusData 

pub struct PlutusData<'a>(/* private fields */);
An arbitrary data format used by Plutus smart contracts.

It can be constructed directly using one of the two variants:

And combine to form larger objects using:

Implementations

Source

impl<'a> PlutusData<'a>

pub fn integer(i: impl Into<BigInt>) -> Self

Construct a data value from an arbitrarily-sized integer.

examples
assert_eq!(
    format!("{}", PlutusData::integer(42)),
    "CBOR(182a)",
);

assert_eq!(
    format!("{}", PlutusData::integer(-14)),
    "CBOR(2d)",
);

assert_eq!(
    format!("{}", PlutusData::integer(BigInt::from(u128::MAX) + BigInt::from(u128::MAX))),
    "CBOR(c25101fffffffffffffffffffffffffffffffe)",
);
pub fn bytes(bytes: impl AsRef<[u8]>) -> Self

Construct an arbitrarily-sized byte-array value.

examples
assert_eq!(
    format!("{}", PlutusData::bytes(b"foo")),
    "CBOR(43666f6f)"
);

assert_eq!(
    format!(
        "{}",
        PlutusData::bytes(
            b"Rerum deleniti nisi ea exercitationem architecto. Quia architecto voluptates error."
        )
    ),
    "CBOR(5f5840526572756d2064656c656e697469206e69736920656120657865726369746174696f6e656d206172636869746563746f2e205175696120617263686974656374536f20766f6c75707461746573206572726f722eff)"
);
pub fn list<T: Into<Self>>(elems: impl IntoIterator<Item = T>) -> Self

Construct an arbitrarily-sized list of self::PlutusData values.

examples

assert_eq!(
    format!("{}", PlutusData::list::<PlutusData>([])),
    "CBOR(80)"
);

assert_eq!(
    format!("{}", PlutusData::list([b"foo", b"bar"])),
    "CBOR(9f43666f6f43626172ff)"
);

assert_eq!(
    format!("{}", PlutusData::list([
        PlutusData::bytes(b"foo"),
        PlutusData::list([1, 2]),
    ])),
    "CBOR(9f43666f6f9f0102ffff)"
);
pub fn map<K: Into<Self>, V: Into<Self>>( kvs: impl IntoIterator<Item = (K, V)>, ) -> Self

Construct an arbitrarily-sized list of self::PlutusData values.

examples

assert_eq!(
    format!("{}", PlutusData::map::<PlutusData, PlutusData>([])),
    "CBOR(a0)"
);

assert_eq!(
    format!(
        "{}",
        PlutusData::map([
            (b"FOO", 1),
            (b"BAR", 2),
        ]),
    ),
    "CBOR(a243464f4f014342415202)"
);
pub fn constr<T: Into<Self>>( ix: u64, fields: impl IntoIterator<Item = T>, ) -> Self

Construct a tagged variant with self::PlutusData fields.

The constructor index `ix` will typically starts at `0`, and be encoded accordingly. You may sometimes see libraries or tools working off encoded indexes (e.g. starting at `121`). This is not the case here.
examples

assert_eq!(
    format!("{}", PlutusData::constr::<PlutusData>(0, [])),
    "CBOR(d87980)"
);

assert_eq!(
    format!(
        "{}",
        PlutusData::constr(0, [
            PlutusData::constr::<PlutusData>(1, []),
            PlutusData::integer(1337),
        ]),
    ),
    "CBOR(d8799fd87a80190539ff)"
);
Source

impl<'a> PlutusData<'a>

pub fn as_integer<T>(&'a self) -> Option<T>
where T: TryFrom<BigInt>,

pub fn as_bytes(&'a self) -> Option<&'a [u8]>

pub fn as_list(&'a self) -> Option<impl Iterator<Item = Self>>

pub fn as_map(&'a self) -> Option<impl Iterator<Item = (Self, Self)>>

pub fn as_constr(&'a self) -> Option<(u64, impl Iterator<Item = Self>)>