ProtocolParameters

Struct ProtocolParameters 

pub struct ProtocolParameters { /* private fields */ }
Protocol parameters restricted to the set immediately useful to this library.

Implementations

Source

impl ProtocolParameters

pub fn mainnet() -> Self

Current Mainnet protocol parameters.

This may drift from actual parameters based on protocol updates. Ideally, parameters should be reconstructed from a blockchain provider.
pub fn preprod() -> Self

Current PreProd protocol parameters.

This may drift from actual parameters based on protocol updates. Ideally, parameters should be reconstructed from a blockchain provider.
pub fn preview() -> Self

Current PreProd protocol parameters.

This may drift from actual parameters based on protocol updates. Ideally, parameters should be reconstructed from a blockchain provider.

FIXME :: This has not been verified.

pub fn posix_to_slot(&self, posix: Duration) -> u64

Translate a posix time to a slot number for that particular network.

pub fn with_fee_per_byte(self, fee_per_byte: u64) -> Self

Specify the multiplier fee coefficient on the size of transactions, in lovelace/bytes

pub fn with_fee_constant(self, fee_constant: u64) -> Self

Flat/fixed fee for all transactions, in lovelace

pub fn with_collateral_coefficient(self, collateral_coefficient: f64) -> Self

Specify the coefficient to apply to fees to obtain the collateral, in lovelace

pub fn with_referenced_scripts_base_fee_per_byte( self, referenced_scripts_base_fee_per_byte: u64, ) -> Self

Specify the initial fee coefficient on the size of referenced scripts, in lovelace/bytes

pub fn with_referenced_scripts_fee_multiplier( self, referenced_scripts_fee_multiplier: Ratio<u64>, ) -> Self

Specify the multiplier exponentially increasing the cost of reference scripts at each size step.

pub fn with_referenced_scripts_fee_step_size( self, referenced_scripts_fee_step_size: u64, ) -> Self

Specify the size of each step after which the cost of referenced script bytes increases, in bytes

pub fn with_execution_price_mem(self, price_mem: f64) -> Self

Specify the price of a single memory execution unit, in lovelace/unit

pub fn with_execution_price_cpu(self, price_cpu: f64) -> Self

Specify the price of a single cpu execution unit, in lovelace/unit

pub fn with_start_time(self, start_time: u64) -> Self

Specify the network POSIX start time, in seconds.

pub fn with_first_shelley_slot(self, first_shelley_slot: u64) -> Self

The first (not-necessarily active) slot of the Shelley era.

pub fn with_plutus_v3_cost_model(self, cost_model: Vec<i64>) -> Self

Specify the cost model for Plutus version 3, ordered according to the “spec”

Source

impl ProtocolParameters

pub fn base_fee(&self, size: u64) -> u64

Base transaction fee, computed from the size of a serialised transaction.

pub fn referenced_scripts_fee(&self, size: u64) -> u64

Compute the tiered-fee of included reference scripts according to ADR- 2024-08-14_009-refscripts-fee-change.

pub fn minimum_collateral(&self, base_fee: u64) -> u64

Compute the minimum collateral value, based on the current transaction fee.

pub fn price_mem(&self, execution_units: u64) -> u64

Compute the price, in lovelace, of memory units usage.

pub fn price_cpu(&self, execution_units: u64) -> u64

Compute the price, in lovelace, of cpu units usage.

pub fn plutus_v3_cost_model(&self) -> &Vec<i64>