pub struct Address<T: IsAddressKind>(/* private fields */);Expand description
An address captures spending and delegation conditions of assets in the network.
Addresses can be one of two kind:
kind::Byron: legacy, not longer used. Also called “bootstrap” addresses sometimes.kind::Shelley: most used and modern format, which can bear delegation rights.
An Address can be constructed in a variety of ways.
-
Either directly using the provided builder:
-
Using the
address!oraddress_test!macros. -
Or by converting from another representation (e.g. bech32, base58 or base16 text strings, or raw bytes):
// Parse a string as Shelley address; will fail if presented with a Byron address: assert!( <Address<kind::Shelley>>::try_from( "addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h" ).is_ok() ); assert!( <Address<kind::Shelley>>::try_from( "Ae2tdPwUPEYwNguM7TB3dMnZMfZxn1pjGHyGdjaF4mFqZF9L3bj6cdhiH8t" ).is_err() );// Parse a string as any address; will also success on Byron addresses: assert!( <Address<kind::Any>>::try_from( "addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h" ).is_ok() ); assert!( <Address<kind::Any>>::try_from( "Ae2tdPwUPEYwNguM7TB3dMnZMfZxn1pjGHyGdjaF4mFqZF9L3bj6cdhiH8t" ).is_ok() );// Also work with base16 encoded addresses: assert!( <Address<kind::Shelley>>::try_from( "61e28b59d19805db228624ffc1830905d0dd51964b134330eb32a9c4b6" ).is_ok() );
Implementations
Sourceimpl Address<Shelley>
impl Address<Shelley>
Sourcepub fn new(network: NetworkId, payment: Credential) -> Self
pub fn new(network: NetworkId, payment: Credential) -> Self
See also address!/address_test!
Sourcepub fn with_delegation(self, delegation: Credential) -> Self
pub fn with_delegation(self, delegation: Credential) -> Self
See also address!/address_test!
Sourceimpl Address<Shelley>
impl Address<Shelley>
pub fn network_id(&self) -> NetworkId
pub fn payment(&self) -> Credential
pub fn delegation(&self) -> Option<Credential>
Sourceimpl<T: IsAddressKind> Address<T>
impl<T: IsAddressKind> Address<T>
Sourcepub fn is_byron(&self) -> bool
pub fn is_byron(&self) -> bool
Check whether an address is a kind::Byron address. To carry this proof at the
type-level, use Self::as_byron.
examples
assert_eq!(
address!(
"37btjrVyb4KDXBNC4haBVPCrro8AQPHwvCMp3R\
FhhSVWwfFmZ6wwzSK6JK1hY6wHNmtrpTf1kdbv\
a8TCneM2YsiXT7mrzT21EacHnPpz5YyUdj64na"
).is_byron(),
true,
);assert_eq!(
address!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h").is_byron(),
false,
);Sourcepub fn as_byron(&self) -> Option<Address<Byron>>
pub fn as_byron(&self) -> Option<Address<Byron>>
Refine the kind of the address, assuming it is a kind::Byron to enable specific methods
for this kind.
Sourcepub fn is_shelley(&self) -> bool
pub fn is_shelley(&self) -> bool
Check whether an address is a kind::Byron address. To carry this proof at the
type-level, use Self::as_shelley.
examples
assert_eq!(
address!(
"37btjrVyb4KDXBNC4haBVPCrro8AQPHwvCMp3R\
FhhSVWwfFmZ6wwzSK6JK1hY6wHNmtrpTf1kdbv\
a8TCneM2YsiXT7mrzT21EacHnPpz5YyUdj64na"
).is_shelley(),
false,
);assert_eq!(
address!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h").is_shelley(),
true,
);Sourcepub fn as_shelley(&self) -> Option<Address<Shelley>>
pub fn as_shelley(&self) -> Option<Address<Shelley>>
Refine the kind of the address, assuming it is a kind::Shelley to enable specific methods
for this kind.