Hash

Struct Hash 

pub struct Hash<const SIZE: usize>(/* private fields */);
A blake2b hash digest; typically 28 or 32 bytes long.

There are several ways to construct Self, but fundamentally:

  • Conversions from static byte arrays of known sizes are infaillible:

    assert_eq!(
      <Hash<28>>::from([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]).to_string(),
      "00000000000000000000000000000000000000000000000000000000",
    );
  • Conversions from vectors or slices are possible but faillible:

    // Vectors contains exactly 28 elements
    assert!(
      <Hash<28>>::try_from(vec![0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
          .is_ok()
    );
    
    // Vectors still contains only 28 elements
    assert!(
      <Hash<32>>::try_from(vec![0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
          .is_err()
    );
  • Conversions from base16-encoded text strings are also possible:

    // The text string is indeed 56 character-long.
    assert!(
      <Hash<28>>::try_from("00000000000000000000000000000000000000000000000000000000")
          .is_ok()
    );
  • For the latter, we also provide the hash! macro.

Implementations

Source

impl Hash<28>

pub fn new<T: AsRef<[u8]>>(preimage: T) -> Self

Source

impl Hash<32>

pub fn new<T: AsRef<[u8]>>(preimage: T) -> Self

Source

impl<const SIZE: usize> Hash<SIZE>

pub const SIZE: usize = SIZE