pub struct Output { /* private fields */ }Expand description
A transaction output, which comprises of at least an Address and a Value<u64>.
The value can be either explicit set using Self::new or defined to the minimum acceptable
by the protocol using Self::to.
Optionally, one can attach an Datum and/or a PlutusScript via
Self::with_datum/Self::with_datum_hash and Self::with_plutus_script respectively.
Implementations
Sourceimpl Output
impl Output
Sourcepub fn new(address: Address<Any>, value: Value<u64>) -> Self
pub fn new(address: Address<Any>, value: Value<u64>) -> Self
Construct a new output from an Address and a Value<u64>. See also Self::to for
constructing a value without an explicit value.
Sourcepub fn to(address: Address<Any>) -> Self
pub fn to(address: Address<Any>) -> Self
Like Self::new, but assumes a minimum lovelace value as output. The value automatically
adjusts based on the other Output’s elements (assets, scripts, etc..).
Sourcepub fn with_assets<AssetName>(
self,
assets: impl IntoIterator<Item = (Hash<28>, impl IntoIterator<Item = (AssetName, u64)>)>,
) -> Self
pub fn with_assets<AssetName>( self, assets: impl IntoIterator<Item = (Hash<28>, impl IntoIterator<Item = (AssetName, u64)>)>, ) -> Self
Attach assets to the output, while preserving the lovelace value.
Sourcepub fn with_plutus_script(self, plutus_script: PlutusScript) -> Self
pub fn with_plutus_script(self, plutus_script: PlutusScript) -> Self
Attach a reference script to the output.
Sourcepub fn with_datum_hash(self, hash: Hash<32>) -> Self
pub fn with_datum_hash(self, hash: Hash<32>) -> Self
Attach a datum reference as Hash<32> to the output.
Sourcepub fn with_datum(self, data: PlutusData<'static>) -> Self
pub fn with_datum(self, data: PlutusData<'static>) -> Self
Attach a plain PlutusData datum to the output.
Sourceimpl Output
impl Output
pub fn address(&self) -> &Address<Any>
pub fn value(&self) -> &Value<u64>
pub fn script(&self) -> Option<&PlutusScript>
pub fn datum(&self) -> Option<&Datum>
Sourcepub fn min_acceptable_value(&self) -> u64
pub fn min_acceptable_value(&self) -> u64
The minimum quantity of lovelace acceptable to carry this output. Address’ delegation, assets, scripts and datums may increase this value.
examples
// Simple, undelegated address. About as low as we can go.
assert_eq!(
output!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h")
.min_acceptable_value(),
857690,
);
// Address with delegation.
assert_eq!(
output!("addr1qytp6yfl9wwamcqu3j5kqhjz8hlgkt62nd82d837g9dlsmn85wjc8sjtq2wqxfmahmpn6h85y0ug7mzclf2jl4zyt3vq587s69")
.min_acceptable_value(),
978370,
);
// Undelegated address with some native assets.
assert_eq!(
output!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h")
.with_assets([
(
hash!("279c909f348e533da5808898f87f9a14bb2c3dfbbacccd631d927a3f"),
[(b"SNEK".to_vec(), 1_000_000_000)]
)
])
.min_acceptable_value(),
1043020,
);
// Undelegated address with some inline datum.
assert_eq!(
output!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h")
.with_datum(PlutusData::list([
PlutusData::integer(14),
PlutusData::integer(42),
PlutusData::bytes(b"foobar"),
]))
.min_acceptable_value(),
935270,
);
// Undelegated address with some datum hash.
assert_eq!(
output!("addr1v83gkkw3nqzakg5xynlurqcfqhgd65vkfvf5xv8tx25ufds2yvy2h")
.with_datum_hash(hash!("279c909f348e533da5808898f87f9a14bb2c3dfbbacccd631d927a3f00000000"))
.min_acceptable_value(),
1017160,
);Trait Implementations
Sourceimpl TryFrom<PseudoTransactionOutput<PseudoPostAlonzoTransactionOutput<Value, PseudoDatumOption<PlutusData>, PseudoScript<NativeScript>>>> for Output
impl TryFrom<PseudoTransactionOutput<PseudoPostAlonzoTransactionOutput<Value, PseudoDatumOption<PlutusData>, PseudoScript<NativeScript>>>> for Output
impl Eq for Output
impl StructuralPartialEq for Output