SigningKey

Struct SigningKey 

pub struct SigningKey(/* private fields */);
An ed25519 signing key (non-extended).

Implementations

Source

impl SigningKey

pub const SIZE: usize = ed25519::SecretKey::SIZE

pub fn new() -> Self

Generate a new signing key using available system entropy.

pub unsafe fn leak(key: Self) -> [u8; 32]

Convert the [SecretKey] into its compressed byte composition, and leak its bytes into memory. Only use for storing the key securely or for testing. Additional precautions are needed to ensure that the leaked bytes are properly de-allocated and cleared.

Safety

This function is not safe because:

  • using it removes all the security measure we put in place to protect your private key: opaque Debug impl, zeroisation on Drop, …
  • you will need to be careful not to leak the bytes
Example
let key: SigningKey = // ...
let _: [u8; SigningKey::SIZE] = unsafe { SigningKey::leak(key) };
pub fn sign<T>(&self, msg: T) -> Signature
where T: AsRef<[u8]>,

Source

impl SigningKey