Value

Struct Value 

pub struct Value<Quantity>(/* private fields */);
A multi-asset value, generic in its asset quantities.

Quantity will typically be instantiated to either u64 or i64 depending on whether it is represent an output value, or a mint value respectively.

Implementations

Source

impl<Quantity> Value<Quantity>

pub fn new(lovelace: u64) -> Self

Construct a new value holding only lovelaces. Use Self::with_assets to add assets if needed.

examples
assert_eq!(Value::<u64>::new(123456789), value!(123_456_789));

See also value!.

pub fn with_lovelace(&mut self, lovelace: u64) -> &mut Self

Replace the amount of lovelaces currently attached to the value.

assert_eq!(
    Value::<u64>::new(14).with_lovelace(42).lovelace(),
    42,
)
Source

impl<Quantity: Zero> Value<Quantity>

pub fn with_assets<AssetName>( self, assets: impl IntoIterator<Item = (Hash<28>, impl IntoIterator<Item = (AssetName, Quantity)>)>, ) -> Self
where AssetName: AsRef<[u8]>,

Attach native assets to the value, replacing any existing assets already set on the value.

examples
assert_eq!(
    Value::new(123456789)
        .with_assets([
            (
                hash!("279c909f348e533da5808898f87f9a14bb2c3dfbbacccd631d927a3f"),
                [( b"SNEK", 1_000_000)]
            ),
        ]),
    value!(
        123_456_789,
        (
            "279c909f348e533da5808898f87f9a14bb2c3dfbbacccd631d927a3f",
            "534e454b",
            1_000_000,
        ),
    ),
);
Source

impl<Quantity: Num + CheckedSub + Copy + Display> Value<Quantity>

pub fn add(&mut self, rhs: &Self) -> &mut Self

Add two values together, removing any entries that results in a null quantity. The latter is possible when quantities can take negative values (e.g. i64).

pub fn checked_sub(&mut self, rhs: &Self) -> Result<&mut Self>

Subtract the right-hand side argument from the current value; returning an error if there’s not enough of a particular quantity on the left-hand side.

examples
assert!(Value::<u64>::new(10).checked_sub(&Value::new(20)).is_err());
let lhs: Value<u64> =
  Value::default()
    .with_assets([
      (
          hash!("b558ea5ecfa2a6e9701dab150248e94104402f789c090426eb60eb60"),
          vec![( Vec::from(b"Snekkie0903"), 1), ( Vec::from(b"Snekkie3556"), 1)],
      ),
      (
          hash!("a0028f350aaabe0545fdcb56b039bfb08e4bb4d8c4d7c3c7d481c235"),
          vec![( Vec::from(b"HOSKY"), 42_000_000)],
      ),
    ]);

assert!(lhs.clone().checked_sub(&lhs).is_ok_and(|value| value == &Value::default()));

let rhs_missing_asset =
  Value::default()
    .with_assets([
      (
          hash!("b558ea5ecfa2a6e9701dab150248e94104402f789c090426eb60eb60"),
          vec![( Vec::from(b"Snekkie9999"), 1)],
      ),
      (
          hash!("a0028f350aaabe0545fdcb56b039bfb08e4bb4d8c4d7c3c7d481c235"),
          vec![( Vec::from(b"HOSKY"), 42_000_000)],
      ),
    ]);

assert!(lhs.clone().checked_sub(&rhs_missing_asset).is_err());

let rhs_missing_script =
  Value::default()
    .with_assets([
      (
          hash!("dcb56b039bfb08e4bb4d8c4d7c3c7d481c235a0028f350aaabe0545f"),
          vec![( Vec::from(b"HOSKY"), 42_000_000)],
      ),
    ]);

assert!(lhs.clone().checked_sub(&rhs_missing_script).is_err());

let rhs_missing_quantity =
  Value::default()
    .with_assets([
      (
          hash!("b558ea5ecfa2a6e9701dab150248e94104402f789c090426eb60eb60"),
          vec![( Vec::from(b"Snekkie0903"), 2)],
      ),
    ]);

assert!(lhs.clone().checked_sub(&rhs_missing_quantity).is_err());
Source

impl<Quantity> Value<Quantity>

pub fn lovelace(&self) -> u64

pub fn assets(&self) -> &BTreeMap<Hash<28>, BTreeMap<Vec<u8>, Quantity>>

pub fn is_empty(&self) -> bool