IsTransactionBodyState

Trait IsTransactionBodyState 

pub trait IsTransactionBodyState: NonExtensible {
    type ChangeStrategy;
}
Restricts the inhabitants that a generic parameter can take. This is used in the context of Transaction to allow some methods to be always accessible, or restricted to a particular state.

For example, the Transaction::sign method is only available in the state ReadyForSigning. This ensures that the body is not inadvertently modified once constructed, as it would invalidate all existing signatures.

Required Associated Types

Implementors