macro_rules! assets {
($( ($script_hash:literal, $asset_name:literal, $amount:expr $(,)?) ),+ $(,)? ) => { ... };
($( ($script_hash:literal, $asset_name:literal, $amount:expr, $redeemer:expr $(,)?) ),+ $(,)? ) => { ... };
}Expand description
Construct a multi-asset object; akin to a Value<u64> but without lovelace.
The second variant of this macro takes an extra PlutusData redeemer.
This is handy to create mint assets, which always come with a redeemer.
See also: